@@ -4,6 +4,7 @@ import os
 import shutil
 import subprocess
 import sys
+import textwrap
 
 from pathlib import Path
 from typing import TYPE_CHECKING
@@ -24,8 +25,8 @@ from tests.helpers import get_package
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
-    from _pytest.fixtures import FixtureRequest
     from poetry.core.packages.package import Package
+    from pytest import FixtureRequest
     from pytest_mock import MockerFixture
 
     from poetry.config.config import Config
@@ -60,39 +61,6 @@ def tester(patches: None) -> CommandTester:
     return CommandTester(app.find("init"))
 
 
-@pytest.fixture
-def init_basic_inputs() -> str:
-    return "\n".join(
-        [
-            "my-package",  # Package name
-            "1.2.3",  # Version
-            "This is a description",  # Description
-            "n",  # Author
-            "MIT",  # License
-            "~2.7 || ^3.6",  # Python
-            "n",  # Interactive packages
-            "n",  # Interactive dev packages
-            "\n",  # Generate
-        ]
-    )
-
-
-@pytest.fixture()
-def init_basic_toml() -> str:
-    return """\
-[tool.poetry]
-name = "my-package"
-version = "1.2.3"
-description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
-readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-"""
-
-
 def test_basic_interactive(
     tester: CommandTester, init_basic_inputs: str, init_basic_toml: str
 ) -> None:
@@ -124,9 +92,17 @@ def test_noninteractive(
     assert tester.io.fetch_output() == expected
     assert tester.io.fetch_error() == ""
 
-    toml_content = (tmp_path / "pyproject.toml").read_text()
+    toml_content = (tmp_path / "pyproject.toml").read_text(encoding="utf-8")
     assert 'name = "my-package"' in toml_content
-    assert 'pytest = "^3.6.0"' in toml_content
+    assert '"pytest (>=3.6.0,<4.0.0)"' in toml_content
+
+    expected_build_system = textwrap.dedent("""
+    [build-system]
+    requires = ["poetry-core>=2.0.0,<3.0.0"]
+    build-backend = "poetry.core.masonry.api"
+    """)
+
+    assert expected_build_system in toml_content
 
 
 def test_interactive_with_dependencies(
@@ -143,7 +119,7 @@ def test_interactive_with_dependencies(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "pendulu",  # Search for package
         "1",  # Second option is pendulum
@@ -162,21 +138,29 @@ def test_interactive_with_dependencies(
     tester.execute(inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "pendulum (>=2.0.0,<3.0.0)",
+    "flask (>=2.0.0,<3.0.0)"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-pendulum = "^2.0.0"
-flask = "^2.0.0"
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
+
+[build-system]
+requires = ["poetry-core>=2.0.0,<3.0.0"]
+build-backend = "poetry.core.masonry.api"
 """
 
     assert expected in tester.io.fetch_output()
@@ -196,7 +180,7 @@ def test_interactive_with_dependencies_and_no_selection(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "pendulu",  # Search for package
         "",  # Do not select an option
@@ -210,16 +194,16 @@ def test_interactive_with_dependencies_and_no_selection(
     ]
     tester.execute(inputs="\n".join(inputs))
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
+requires-python = ">=3.6"
 """
 
     assert expected in tester.io.fetch_output()
@@ -241,15 +225,15 @@ def test_empty_license(tester: CommandTester) -> None:
 
     python = ".".join(str(c) for c in sys.version_info[:2])
     expected = f"""\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = ""
-authors = ["Your Name <you@example.com>"]
+authors = [
+    {{name = "Your Name",email = "you@example.com"}}
+]
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "^{python}"
+requires-python = ">={python}"
 """
     assert expected in tester.io.fetch_output()
 
@@ -266,7 +250,7 @@ def test_interactive_with_git_dependencies(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "git+https://github.com/demo/demo.git",  # Search for package
         "",  # Stop searching for packages
@@ -280,17 +264,21 @@ def test_interactive_with_git_dependencies(
     tester.execute(inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ git+https://github.com/demo/demo.git"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {git = "https://github.com/demo/demo.git"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -358,7 +346,7 @@ def test_interactive_with_git_dependencies_with_reference(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "git+https://github.com/demo/demo.git@develop",  # Search for package
         "",  # Stop searching for packages
@@ -372,17 +360,21 @@ def test_interactive_with_git_dependencies_with_reference(
     tester.execute(inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ git+https://github.com/demo/demo.git@develop"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {git = "https://github.com/demo/demo.git", rev = "develop"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -403,7 +395,7 @@ def test_interactive_with_git_dependencies_and_other_name(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "git+https://github.com/demo/pyproject-demo.git",  # Search for package
         "",  # Stop searching for packages
@@ -417,17 +409,21 @@ def test_interactive_with_git_dependencies_and_other_name(
     tester.execute(inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ git+https://github.com/demo/pyproject-demo.git"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {git = "https://github.com/demo/pyproject-demo.git"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -454,7 +450,7 @@ def test_interactive_with_directory_dependency(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "./demo",  # Search for package
         "",  # Stop searching for packages
@@ -467,18 +463,23 @@ def test_interactive_with_directory_dependency(
     ]
     tester.execute(inputs="\n".join(inputs))
 
-    expected = """\
-[tool.poetry]
+    demo_uri = (Path.cwd() / "demo").as_uri()
+    expected = f"""\
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {{name = "Your Name",email = "you@example.com"}}
+]
+license = {{text = "MIT"}}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ {demo_uri}"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {path = "demo"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -504,7 +505,7 @@ def test_interactive_with_directory_dependency_and_other_name(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "./pyproject-demo",  # Search for package
         "",  # Stop searching for packages
@@ -517,18 +518,23 @@ def test_interactive_with_directory_dependency_and_other_name(
     ]
     tester.execute(inputs="\n".join(inputs))
 
-    expected = """\
-[tool.poetry]
+    demo_uri = (Path.cwd() / "pyproject-demo").as_uri()
+    expected = f"""\
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {{name = "Your Name",email = "you@example.com"}}
+]
+license = {{text = "MIT"}}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ {demo_uri}"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {path = "pyproject-demo"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -555,7 +561,7 @@ def test_interactive_with_file_dependency(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "./demo-0.1.0-py2.py3-none-any.whl",  # Search for package
         "",  # Stop searching for packages
@@ -568,18 +574,23 @@ def test_interactive_with_file_dependency(
     ]
     tester.execute(inputs="\n".join(inputs))
 
-    expected = """\
-[tool.poetry]
+    demo_uri = (Path.cwd() / "demo-0.1.0-py2.py3-none-any.whl").as_uri()
+    expected = f"""\
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {{name = "Your Name",email = "you@example.com"}}
+]
+license = {{text = "MIT"}}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+    "demo @ {demo_uri}"
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-demo = {path = "demo-0.1.0-py2.py3-none-any.whl"}
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -597,7 +608,7 @@ def test_interactive_with_wrong_dependency_inputs(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "^3.8",  # Python
+        ">=3.8",  # Python
         "",  # Interactive packages
         "foo 1.19.2",
         "pendulum 2.0.0 foo",  # Package name and constraint (invalid)
@@ -613,18 +624,22 @@ def test_interactive_with_wrong_dependency_inputs(
     tester.execute(inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.8"
+dependencies = [
+    "foo (==1.19.2)",
+    "pendulum (>=2.0.0,<3.0.0)"
+]
 
-[tool.poetry.dependencies]
-python = "^3.8"
-foo = "1.19.2"
-pendulum = "^2.0.0"
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "3.6.0"
@@ -644,19 +659,19 @@ def test_python_option(tester: CommandTester) -> None:
         "n",  # Interactive dev packages
         "\n",  # Generate
     ]
-    tester.execute("--python '~2.7 || ^3.6'", inputs="\n".join(inputs))
+    tester.execute("--python '>=3.6'", inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
+requires-python = ">=3.6"
 """
 
     assert expected in tester.io.fetch_output()
@@ -671,7 +686,7 @@ def test_predefined_dependency(tester: CommandTester, repo: TestRepository) -> N
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "n",  # Interactive packages
         "n",  # Interactive dev packages
         "\n",  # Generate
@@ -679,17 +694,19 @@ def test_predefined_dependency(tester: CommandTester, repo: TestRepository) -> N
     tester.execute("--dependency pendulum", inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
-pendulum = "^2.0.0"
+requires-python = ">=3.6"
+dependencies = [
+    "pendulum (>=2.0.0,<3.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -707,7 +724,7 @@ def test_predefined_and_interactive_dependencies(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "",  # Interactive packages
         "pyramid",  # Search for package
         "0",  # First option
@@ -720,21 +737,22 @@ def test_predefined_and_interactive_dependencies(
     tester.execute("--dependency pendulum", inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
+requires-python = ">=3.6"
+dependencies = [
+    "pendulum (>=2.0.0,<3.0.0)",
+    "pyramid (>=1.10,<2.0)"
+]
 """
-    output = tester.io.fetch_output()
-    assert expected in output
-    assert 'pendulum = "^2.0.0"' in output
-    assert 'pyramid = "^1.10"' in output
+    assert expected in tester.io.fetch_output()
 
 
 def test_predefined_dev_dependency(tester: CommandTester, repo: TestRepository) -> None:
@@ -746,7 +764,7 @@ def test_predefined_dev_dependency(tester: CommandTester, repo: TestRepository)
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "n",  # Interactive packages
         "n",  # Interactive dev packages
         "\n",  # Generate
@@ -755,16 +773,20 @@ def test_predefined_dev_dependency(tester: CommandTester, repo: TestRepository)
     tester.execute("--dev-dependency pytest", inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -785,7 +807,7 @@ def test_predefined_and_interactive_dev_dependencies(
         "This is a description",  # Description
         "n",  # Author
         "MIT",  # License
-        "~2.7 || ^3.6",  # Python
+        ">=3.6",  # Python
         "n",  # Interactive packages
         "",  # Interactive dev packages
         "pytest-requests",  # Search for package
@@ -798,16 +820,20 @@ def test_predefined_and_interactive_dev_dependencies(
     tester.execute("--dev-dependency pytest", inputs="\n".join(inputs))
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Your Name <you@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.6"
+dependencies = [
+]
 
-[tool.poetry.dependencies]
-python = "~2.7 || ^3.6"
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -836,7 +862,7 @@ def test_predefined_all_options(tester: CommandTester, repo: TestRepository) ->
         "--name my-package "
         "--description 'This is a description' "
         "--author 'Foo Bar <foo@example.com>' "
-        "--python '^3.8' "
+        "--python '>=3.8' "
         "--license MIT "
         "--dependency pendulum "
         "--dev-dependency pytest",
@@ -844,17 +870,21 @@ def test_predefined_all_options(tester: CommandTester, repo: TestRepository) ->
     )
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "1.2.3"
 description = "This is a description"
-authors = ["Foo Bar <foo@example.com>"]
-license = "MIT"
+authors = [
+    {name = "Foo Bar",email = "foo@example.com"}
+]
+license = {text = "MIT"}
 readme = "README.md"
+requires-python = ">=3.8"
+dependencies = [
+    "pendulum (>=2.0.0,<3.0.0)"
+]
 
-[tool.poetry.dependencies]
-python = "^3.8"
-pendulum = "^2.0.0"
+[tool.poetry]
 
 [tool.poetry.group.dev.dependencies]
 pytest = "^3.6.0"
@@ -886,9 +916,11 @@ def test_init_existing_pyproject_simple(
 [tool.black]
 line-length = 88
 """
-    pyproject_file.write_text(existing_section)
+    pyproject_file.write_text(existing_section, encoding="utf-8")
     tester.execute(inputs=init_basic_inputs)
-    assert f"{existing_section}\n{init_basic_toml}" in pyproject_file.read_text()
+    assert f"{existing_section}\n{init_basic_toml}" in pyproject_file.read_text(
+        encoding="utf-8"
+    )
 
 
 @pytest.mark.parametrize("linesep", ["\n", "\r\n"])
@@ -904,10 +936,10 @@ def test_init_existing_pyproject_consistent_linesep(
 [tool.black]
 line-length = 88
 """.replace("\n", linesep)
-    with open(pyproject_file, "w", newline="") as f:
+    with open(pyproject_file, "w", newline="", encoding="utf-8") as f:
         f.write(existing_section)
     tester.execute(inputs=init_basic_inputs)
-    with open(pyproject_file, newline="") as f:
+    with open(pyproject_file, newline="", encoding="utf-8") as f:
         content = f.read()
     init_basic_toml = init_basic_toml.replace("\n", linesep)
     assert f"{existing_section}{linesep}{init_basic_toml}" in content
@@ -924,31 +956,35 @@ def test_init_non_interactive_existing_pyproject_add_dependency(
 [tool.black]
 line-length = 88
 """
-    pyproject_file.write_text(existing_section)
+    pyproject_file.write_text(existing_section, encoding="utf-8")
 
     repo.add_package(get_package("foo", "1.19.2"))
 
     tester.execute(
         "--author 'Your Name <you@example.com>' "
         "--name 'my-package' "
-        "--python '^3.6' "
+        "--python '>=3.6' "
         "--dependency foo",
         interactive=False,
     )
 
     expected = """\
-[tool.poetry]
+[project]
 name = "my-package"
 version = "0.1.0"
 description = ""
-authors = ["Your Name <you@example.com>"]
+authors = [
+    {name = "Your Name",email = "you@example.com"}
+]
 readme = "README.md"
-
-[tool.poetry.dependencies]
-python = "^3.6"
-foo = "^1.19.2"
+requires-python = ">=3.6"
+dependencies = [
+    "foo (>=1.19.2,<2.0.0)"
+]
 """
-    assert f"{existing_section}\n{expected}" in pyproject_file.read_text()
+    assert f"{existing_section}\n{expected}" in pyproject_file.read_text(
+        encoding="utf-8"
+    )
 
 
 def test_init_existing_pyproject_with_build_system_fails(
@@ -960,13 +996,13 @@ def test_init_existing_pyproject_with_build_system_fails(
 requires = ["setuptools >= 40.6.0", "wheel"]
 build-backend = "setuptools.build_meta"
 """
-    pyproject_file.write_text(existing_section)
+    pyproject_file.write_text(existing_section, encoding="utf-8")
     tester.execute(inputs=init_basic_inputs)
     assert (
         tester.io.fetch_error().strip()
         == "A pyproject.toml file with a defined build-system already exists."
     )
-    assert existing_section in pyproject_file.read_text()
+    assert existing_section in pyproject_file.read_text(encoding="utf-8")
 
 
 @pytest.mark.parametrize(
@@ -995,6 +1031,22 @@ def test_validate_package_invalid(name: str) -> None:
         assert InitCommand._validate_package(name)
 
 
+@pytest.mark.parametrize(
+    "author",
+    [
+        str(b"Jos\x65\xcc\x81 Duarte", "utf-8"),
+        str(b"Jos\xc3\xa9 Duarte", "utf-8"),
+    ],
+)
+def test_validate_author(author: str) -> None:
+    """
+    This test was added following issue #8779, hence, we're looking to see if the test
+    no longer throws an exception, hence the seemingly "useless" test of just running
+    the method.
+    """
+    InitCommand._validate_author(author, "")
+
+
 @pytest.mark.parametrize(
     "package_name, include",
     (
@@ -1018,7 +1070,7 @@ def test_package_include(
                 "",  # Description
                 "poetry",  # Author
                 "",  # License
-                "^3.10",  # Python
+                ">=3.10",  # Python
                 "n",  # Interactive packages
                 "n",  # Interactive dev packages
                 "\n",  # Generate
@@ -1028,32 +1080,34 @@ def test_package_include(
 
     packages = ""
     if include and module_name(package_name) != include:
-        packages = f'packages = [{{include = "{include}"}}]\n'
+        packages = f'\n[tool.poetry]\npackages = [{{include = "{include}"}}]\n'
 
     expected = (
-        f"[tool.poetry]\n"
+        "[project]\n"
         f'name = "{package_name.replace(".", "-")}"\n'  # canonicalized
-        f'version = "0.1.0"\n'
-        f'description = ""\n'
-        f'authors = ["poetry"]\n'
-        f'readme = "README.md"\n'
-        f"{packages}"  # This line is optional. Thus no newline here.
-        f"\n"
-        f"[tool.poetry.dependencies]\n"
-        f'python = "^3.10"\n'
+        'version = "0.1.0"\n'
+        'description = ""\n'
+        'authors = [\n'
+        '    {name = "poetry"}\n'
+        ']\n'
+        'readme = "README.md"\n'
+        'requires-python = ">=3.10"\n'
+        'dependencies = [\n'
+        ']\n'
+        f"{packages}"  # This line is optional. Thus, no newline here.
     )
     assert expected in tester.io.fetch_output()
 
 
 @pytest.mark.parametrize(
-    ["prefer_active", "python"],
+    ["use_poetry_python", "python"],
     [
-        (True, "1.1"),
-        (False, f"{sys.version_info[0]}.{sys.version_info[1]}"),
+        (False, "1.1"),
+        (True, f"{sys.version_info[0]}.{sys.version_info[1]}"),
     ],
 )
-def test_respect_prefer_active_on_init(
-    prefer_active: bool,
+def test_respect_use_poetry_python_on_init(
+    use_poetry_python: bool,
     python: str,
     config: Config,
     mocker: MockerFixture,
@@ -1072,8 +1126,11 @@ def test_respect_prefer_active_on_init(
         return result
 
     mocker.patch("subprocess.check_output", side_effect=mock_check_output)
-
-    config.config["virtualenvs"]["prefer-active-python"] = prefer_active
+    mocker.patch(
+        "poetry.utils.env.python_manager.Python._full_python_path",
+        return_value=Path(f"/usr/bin/python{python}"),
+    )
+    config.config["virtualenvs"]["use-poetry-python"] = use_poetry_python
     pyproject_file = source_dir / "pyproject.toml"
 
     tester.execute(
@@ -1082,11 +1139,10 @@ def test_respect_prefer_active_on_init(
     )
 
     expected = f"""\
-[tool.poetry.dependencies]
-python = "^{python}"
+requires-python = ">={python}"
 """
 
-    assert expected in pyproject_file.read_text()
+    assert expected in pyproject_file.read_text(encoding="utf-8")
 
 
 def test_get_pool(mocker: MockerFixture, source_dir: Path) -> None:
